# Optipyzer API
# Nathan J. LeRoy
# See LICENSE for details

import sys

from .const import LICENSE, VERSION
assert sys.version_info[0] == 3, "Optipyzer requires Python 3.0 or greater"

"""A library that provides a Python interface to the Optipyzer API"""

__author__ = 'Nathan J. LeRoy'
__url__ = 'https://github.com/NLeRoy917/optipyzer.com'
__description__ = 'A Python wrapper around the Optipyzer API'
__license__ = LICENSE
__version__ = VERSION